@@ -4,15 +4,6 @@ import logging
 
 logger = logging.getLogger(__name__)
 
-
-# ! Main config
-class CoreConfig:
-    ROOT_DIR = ".ai-kit"
-    INDEX_DIR = "files"  # Directory for indexed content
-    CHAT_DIR = "chats"  # Directory for chat history
-    SUPPORTED_FILE_EXTENSIONS = [".txt", ".md", ".pdf"]
-
-
 # ! LLM Config
 class LiteLLMConfig:
     """Model configurations that can be customized by users."""
@@ -21,6 +12,7 @@ class LiteLLMConfig:
     DEFAULT_CHAT_MODEL = "gpt-4o"
     DEFAULT_REASONING_MODEL = "o1"
     DEFAULT_EMBEDDING_MODEL = "text-embedding-3-small"
+    DEFAULT_RERANK_MODEL = "rerank-v3.5"
 
     # Supported models - add or remove based on your needs
     SUPPORTED_CHAT_MODELS = [
@@ -29,6 +21,7 @@ class LiteLLMConfig:
         "llama-3.1-70B-instruct",
         "llama-3.3-70b-versatile",
         "claude-3.5-sonnet",
+        "gemini-2.0-flash"
     ]
     SUPPORTED_REASONING_MODELS = [
         "o1-mini",
@@ -37,8 +30,13 @@ class LiteLLMConfig:
         "o3-mini",
         "gemini-2.0-flash-thinking",
         "r1-together",
+        "r1-70b"
     ]
     SUPPORTED_EMBEDDING_MODELS = ["text-embedding-3-small", "text-embedding-3-large"]
+    SUPPORTED_RERANK_MODELS = [
+        "rerank-english-v3.0",
+        "rerank-v3.5",
+    ]
 
     # Model mappings (optional)
     MODEL_MAPPINGS = {
@@ -52,7 +50,15 @@ class LiteLLMConfig:
         "gemini-2.0-flash-thinking": "gemini-2.0-flash-thinking-exp-01-21",
         # groq
         "llama-3.3-70b-versatile": "groq/llama-3.3-70b-versatile",
+        "r1-70b": "deepseek-r1-distill-llama-70b",
+        # anthropic
         "claude-3.5-sonnet": "anthropic/claude-3-5-sonnet-latest",
+        # cohere
+        "rerank-english-v3.0": "cohere/rerank-english-v3.0",
+        "rerank-v3.5": "cohere/rerank-v3.5",
+        # google
+        "gemini-2.0-flash": "gemini-2.0-flash-exp",
+        
     }
 
     # Required API keys for different providers (optional)
@@ -66,6 +72,9 @@ class LiteLLMConfig:
         "llama-3.1-8B-instruct": "TOGETHER_API_KEY",
         "gemini-2.0-flash-thinking": "GEMINI_API_KEY",
         "claude-3.5-sonnet": "ANTHROPIC_API_KEY",
+        "rerank-english-v3.0": "COHERE_API_KEY",
+        "gemini-2.0-flash": "GEMINI_API_KEY",
+        "r1-70b": "GROQ_API_KEY",
     }
 
     # Model dimension mappings for embeddings
